@@ -1,5 +1,5 @@
 /*
-** Copyright 2000-2003 Double Precision, Inc.
+** Copyright 2000-2006 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -41,7 +41,7 @@
 #include	"maildircreate.h"
 #include	"maildirsharedrc.h"
 
-static const char rcsid[]="$Id: maildirshared.c,v 1.21 2005/06/19 13:15:28 mrsam Exp $";
+static const char rcsid[]="$Id: maildirshared.c,v 1.22 2006/05/28 15:29:52 mrsam Exp $";
 
 /* Prerequisited for shared folder support */
 
@@ -754,7 +754,8 @@ int	fd;
 	}
 	if ((fd=maildir_safeopen(shared_update_name, O_RDWR|O_CREAT, 0600))>= 0)
 	{
-		write(fd, "", 1);
+		if (write(fd, "", 1) < 0)
+			perror("write");
 		close(fd);
 	}
 
