@@ -1,7 +1,7 @@
 #ifndef	message_h
 #define	message_h
 
-static const char message_h_rcsid[]="$Id: message.h,v 1.4 1999/06/02 01:59:07 mrsam Exp $";
+static const char message_h_rcsid[]="$Id: message.h,v 1.5 2003/01/26 15:45:16 mrsam Exp $";
 
 //////////////////////////////////////////////////////////////////////////////
 //
@@ -73,7 +73,7 @@ public:
 	off_t tell();
 	int get_c();
 	int peek();
-	off_t MessageSize() { return (msgsize); }
+	off_t MessageSize();
 	off_t MessageLines() { return (msglines); }
 	void setmsgsize();
 	} ;
@@ -172,4 +172,14 @@ int	l=0;
 	}
 }
 
+inline off_t Message::MessageSize()
+{
+	off_t s=msgsize;
+	s -= maildrop.msginfo.msgoffset;
+	if (extra_headers)
+		s += strlen(extra_headers);
+
+	return (s);
+}
+
 #endif
